#A Simple Test program to generate small Generalized Model Food Webs based on the niche model algorithm 
#presented in "Simple rules yield complex food webs", Science 404,by R.J. Williams and N.D. Martinez, 2000
# and parametrized as generalized model using the Generalized Modelling Parameters
# presented in "Generalized models as a universal approach to the analysis of nonlinear dynamical systems", Phys. Rev. E. 73, by T. Gross and U. Feudel, 2006

####################################################################
#(C) BY H.AUFDERHEIDE 
# THIS SCRIPT IS DISTRIBUTED AS-IS
# YOU USE IT AT YOUR OWN RISK
#
## This work is licensed under the Creative Commons Attribution-NonCommercial 3.0 Unported License.
# To view a copy of this license, visit http://creativecommons.org/licenses/by-nc/3.0/ or
# send a letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
#
# The author takes no responsability whatshowever for the correctness and correct function of this script
# and is not liable for any damage caused through its correct or incorrect use.
######################################################################
#USAGE:
#YOU CAN RUN IT WITH WITH THE COMMAND 
#python ./NicheWebTester.py <N> <C> <Req_Stable>
# where <N> is the desired number of species
# where <C> is the desired connectance
# where <Req_Stable> can be 0 or 1 indicating if the process should loop until a stable configuration is found.
# if no parameters are given, the defaults are used 
# <N=10> <C=0.2> <Req_Stable=0>
# This will output the generated Adjacency matrix, the GM Parameters and the Jacobian Matrix, as well as indicate if the configuration is stable.
#########################################################################################################################

import sys	#Command line parameter parsing
from webheader import FoodWebModel	#The header file containing the niche model generator and the GM parametrizer

#########################################################################################################################
## T E S T     P R O G R A M ############################################################################################

##SETTING PARAMETERS FOR A MODEL FOOD WEB: ##############################################################################

N=10 			#Default Number of Species
C=0.2			#Default Connectance
Req_Stable=False	#Requiring a stable web (can be slow for high N*C, because unstable ones are thrown away and stability is ~ exp(-NC))
			
if len(sys.argv)>1:  N=int(sys.argv[1])	#Or overwrite the parameters from command line arguments
if len(sys.argv)>2:  C=float(sys.argv[2])
if len(sys.argv)>3:  Req_Stable=bool(sys.argv[3])
 
  
##DEFINE HOW TO CREATE THE Generalized Model FOOD WEB  #################################################################################
def WebMaker(Web):
  Web.makeNicheFW(N,C)		#Create a Model Food Web Adjacency
  
  Web.makeRandomModel()		#Parametrize randomly
  Web.makeRateScalingbyNiche()	#Scale turnover rates allometrically by niche values
  
  Web.makeJacobian()		#Calculate Jacobian
##########################################################################################################################

##DO IT##################################################################################################

Web=FoodWebModel()		#Prepare an empty web

WebMaker(Web)			#Create a Web as defined aove

if Req_Stable:		#if we require a stable web: Redo makeWeb() until we found one
  while(not Web.testStability()):
    print "Web is UNSTABLE -> Rerun \n"
    WebMaker(Web)
    
if Web.testStability():  print "Web Configuration is STABLE"	#Indication if the Web is stable
else:  print "Web Configuration is UNSTABLE"		


##OUTPUT:	################################################################################################

Web.printAdjacency("Adjacency.txt")		#Printin Final Adjacency Matrix
Web.printParameters("Parameters.txt")	#Printing Final Parameters
Web.printJacobian("JacobianMatrix.txt") #Printing Final Jacobian Matrix

	
#########################################################################################################################
 