#A Simple Test program to load and parameterize real/world food web topologies according to the Generalized Modelling process
# presented in "Generalized models as a universal approach to the analysis of nonlinear dynamical systems", Phys. Rev. E. 73, by T. Gross and U. Feudel, 2006

####################################################################
#(C) BY H.AUFDERHEIDE 
# THIS SCRIPT IS DISTRIBUTED AS-IS
# YOU USE IT AT YOUR OWN RISK
#
## This work is licensed under the Creative Commons Attribution-NonCommercial 3.0 Unported License.
# To view a copy of this license, visit http://creativecommons.org/licenses/by-nc/3.0/ or
# send a letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
#
# The author takes no responsability whatshowever for the correctness and correct function of this script
# and is not liable for any damage caused through its correct or incorrect use.
######################################################################
#USAGE:
#YOU CAN RUN IT WITH THE COMMAND 
#python ./RealWebTester.py <Adjacency-File>
#Adjacency-File defaults to the included Gatun Lake Food Web Adjacency, to which the parameterization is adapted.
# This will output the GM Parameters and the Jacobian Matrix, as well as indicate if the configuration is stable.
#########################################################################################################################

import sys			#Command line parameter parsing
from webheader import FoodWebModel	#The header file containing the niche model generator and the GM parametrizer

#########################################################################################################################
## T E S T     P R O G R A M ############################################################################################

##SETTING PARAMETERS: ##############################################################################

filename="ExampleAdj.lma" 			#Default Filename for Adjacency File
if len(sys.argv)>1:  filename=sys.argv[1]	#Or overwrite the Filname from command line argument
  

##CREATING A Generalized Model FOOD WEB  #################################################################################

Web=FoodWebModel()		#Prepare an empty web

Web.loadAdjFile(filename,0.01)	#Load Food Web Adjacency (and do a weak randomization to avoid singular webs)
Web.makeDummyModel(0.12)		#Parametrize with "Dummy" Parameters (see paper supplement for details)

Web.makeBetaFromChi()

#General settings
psibirds=1.02
Web.adjustModelElasticities(psi=[1.,1.,1.,1.,1.,1.,1.,1.,1.,1.0,psibirds,psibirds],gamma=0.95) #Set psi sublinear for potential cannibals
Web.makeRateScalingbyBM([0.000001,0.0003,0.002,0.003,5.2,49,0.9,400,1716,24000,55,800],0.00485) #Each species approximate weight in g to scale the turnover rates. The prefactor 0.00485 garantees compatibility with empirical data.

#Explicit empirical data:
Web.alpha[9]=0.33 #Tarpon atlanticus
Web.alpha[8]=0.38 #Gobiormus
Web.alpha[2]=30  #Zooplancton
Web.alpha[3]=5  #Insects
Web.alpha[0]=203.3 #Nanophytoplancton
Web.alpha[1]=30  #Filamentous algae

Web.makeJacobian()		#Calculate Jacobian

if Web.testStability():  print "Web Configuration is STABLE"	#Indication if the Web is stable
else:  print "Web Configuration is UNSTABLE"		
#print Web.getEigenvalues()					#Switch on to see the eigenvalues

##OUTPUT:	################################################################################################
Web.printParameters("ParametersD.txt")	#Printing Final Parameters
Web.printJacobian("JacobianD.txt") #Printing Final Jacobian Matrix

#########################################################################################################################
 